@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1995 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -36,10 +36,11 @@
 
 #include "Dino.h"
 
-typedef struct _Dino2DClassRec *Dino2DWidgetClass;
 typedef struct _Dino2DRec *Dino2DWidget;
-
+#ifndef WINVER
+typedef struct _Dino2DClassRec *Dino2DWidgetClass;
 extern WidgetClass dino2dWidgetClass;
+#endif
 
 #endif /* _XtDino2d_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
