@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1995 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -30,26 +30,7 @@
 
 #include "Dino2d.h"
 
-#define FRONTLOC 0
-#define BACKLOC 11
-#define COORD2D 8
-#define MAXX 3
-#define MAXY 4
-#define MAXXY 4			/* (MAX(MAXX,MAXY)) */
-#define MAXRECT (MAXX*MAXY)
-
-typedef struct _Dino2DPart {
-	Position    diamondLength, triangleLength, triangleWidth;
-	Position    faceLength;
-	Position    viewLength;
-} Dino2DPart;
-
-typedef struct _Dino2DRec {
-	CorePart    core;
-	DinoPart    dino;
-	Dino2DPart  dino2d;
-} Dino2DRec;
-
+#ifndef WINVER
 /* This gets around C's inability to do inheritance */
 typedef struct _Dino2DClassPart {
 	int         ignore;
@@ -62,9 +43,37 @@ typedef struct _Dino2DClassRec {
 } Dino2DClassRec;
 
 extern Dino2DClassRec dino2dClassRec;
+#endif
 
-extern int  SelectPolyhedrons2D(Dino2DWidget w, int x, int y, int *face, int *position);
-extern int  NarrowSelection2D(Dino2DWidget w, int *face, int *direction);
+#define FRONTLOC 0
+#define BACKLOC 11
+#define COORD2D 8
+#define MAXX 3
+#define MAXY 4
+#define MAXXY 4			/* (MAX(MAXX,MAXY)) */
+#define MAXRECT (MAXX*MAXY)
+
+typedef struct _Dino2DPart {
+	Position diamondLength, triangleLength, triangleWidth;
+	Position faceLength;
+	Position viewLength;
+} Dino2DPart;
+
+typedef struct _Dino2DRec {
+	CorePart    core;
+	DinoPart    dino;
+	Dino2DPart  dino2d;
+} Dino2DRec;
+
+extern Boolean SelectPieces2D(Dino2DWidget w, int x, int y,
+	int *face, int *position);
+extern Boolean NarrowSelection2D(Dino2DWidget w, int *face, int *direction);
+extern void DrawFrame2D(Dino2DWidget w, Boolean focus);
 extern void DrawTriangle2D(Dino2DWidget w, int face, int position, int offset);
+#ifdef WINVER
+extern void ResizeDino2D(Dino2DWidget w);
+extern void InitializeDino2D(Dino2DWidget w);
+extern void ExposeDino2D(Dino2DWidget w);
+#endif
 
 #endif /* _Dino2dP_h */
