@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1995 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -30,6 +30,21 @@
 
 #include "Dino3d.h"
 
+#ifndef WINVER
+/* This gets around C's inability to do inheritance */
+typedef struct _Dino3DClassPart {
+	int         ignore;
+} Dino3DClassPart;
+
+typedef struct _Dino3DClassRec {
+	CoreClassPart coreClass;
+	DinoClassPart dinoClass;
+	Dino3DClassPart dino3dClass;
+} Dino3DClassRec;
+
+extern Dino3DClassRec dino3dClassRec;
+#endif
+
 #define SAME 0
 #define OPPOSITE 1
 #define DOWN 0
@@ -44,8 +59,8 @@
 
 typedef struct _Dino3DPart {
 	Position    cubeDiagonal, cubeDiag, diamondDiagonal, faceDiagonal;
-	XPoint      cubeSize, diamondSize, faceSize, viewSize;
-	XPoint      viewMiddle;
+	Point       cubeSize, diamondSize, faceSize, viewSize;
+	Point       viewMiddle;
 } Dino3DPart;
 
 typedef struct _Dino3DRec {
@@ -54,21 +69,15 @@ typedef struct _Dino3DRec {
 	Dino3DPart  dino3d;
 } Dino3DRec;
 
-/* This gets around C's inability to do inheritance */
-typedef struct _Dino3DClassPart {
-	int         ignore;
-} Dino3DClassPart;
-
-typedef struct _Dino3DClassRec {
-	CoreClassPart coreClass;
-	DinoClassPart dinoClass;
-	Dino3DClassPart dino3dClass;
-} Dino3DClassRec;
-
-extern Dino3DClassRec dino3dClassRec;
-
-extern int  SelectPolyhedrons3D(Dino3DWidget w, int x, int y, int *face, int *position);
-extern int  NarrowSelection3D(Dino3DWidget w, int *face, int *direction);
+extern Boolean SelectPieces3D(Dino3DWidget w, int x, int y,
+	int *face, int *position);
+extern Boolean NarrowSelection3D(Dino3DWidget w, int *face, int *direction);
+extern void DrawFrame3D(Dino3DWidget w, Boolean focus);
 extern void DrawTriangle3D(Dino3DWidget w, int face, int position, int offset);
+#ifdef WINVER
+extern void ResizeDino3D(Dino3DWidget w);
+extern void InitializeDino3D(Dino3DWidget w);
+extern void ExposeDino3D(Dino3DWidget w);
+#endif
 
 #endif /* _Dino3dP_h */
