@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1995 - 2004	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -25,43 +25,33 @@
 
 /* Undo algorithm */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
 #include "DinoP.h"
-#include "Dino2dP.h"
-#include "Dino3dP.h"
 
 typedef struct _MoveRecord {
-	/* int face, position, direction, style, control; */
+#if 0
+	int face, position, direction, style, control;
+#endif
 	unsigned long int packed;	/* This makes assumptions on the data. */
 } MoveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord  move;
+	MoveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
 static MoveStack *currMove, *lastMove, *firstMove;
-static int  count;
+static int count;
 static DinoCornerLoc startLoc[MAXFACES][MAXORIENT];
 
-static void InitStack(void);
-static void PushStack(MoveRecord move);
-static void PopStack(MoveRecord * move);
-static int  EmptyStack(void);
-static void FlushStack(void);
-
 static void
 InitStack(void)
 {
-	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
-	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	firstMove->previous = lastMove->next = NULL;
 	firstMove->next = lastMove;
 	lastMove->previous = firstMove;
@@ -71,8 +61,9 @@ InitStack(void)
 static void
 PushStack(MoveRecord move)
 {
-	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	lastMove->previous->next = currMove;
 	currMove->previous = lastMove->previous;
 	currMove->next = lastMove;
@@ -121,8 +112,13 @@ InitMoves(void)
 static void
 WriteMove(MoveRecord * move, int face, int position, int direction, int style, int control)
 {
-	/* move->face = face; moves->position = position;
-	   move->direction = direction; move->style = style;  move->control = control; */
+#if 0
+	move->face = face;
+	moves->position = position;
+	move->direction = direction;
+	move->style = style;
+	move->control = control;
+#endif
 	move->packed = ((control & 0xF) << 16) + ((style & 0xF) << 12) +
 		((direction & 0xF) << 8) + ((position & 0xF) << 4) + (face & 0xF);
 }
@@ -130,19 +126,24 @@ WriteMove(MoveRecord * move, int face, int position, int direction, int style, i
 static void
 ReadMove(int *face, int *position, int *direction, int *style, int *control, MoveRecord move)
 {
-	/* *face = move.face; *position = move.position; *direction = move.direction;
-	   *style = move.style; *control = move.control; */
-	*face = move.packed & 0xF;
-	*position = (move.packed >> 4) & 0xF;
-	*direction = (move.packed >> 8) & 0xF;
-	*style = (move.packed >> 12) & 0xF;
-	*control = (move.packed >> 16) & 0xF;
+#if 0
+	*face = move.face;
+	*position = move.position;
+	*direction = move.direction;
+	*style = move.style;
+	*control = move.control;
+#endif
+	*face = (int) (move.packed & 0xF);
+	*position = (int) ((move.packed >> 4) & 0xF);
+	*direction = (int) ((move.packed >> 8) & 0xF);
+	*style = (int) ((move.packed >> 12) & 0xF);
+	*control = (int) ((move.packed >> 16) & 0xF);
 }
 
 void
 PutMove(int face, int position, int direction, int style, int control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	WriteMove(&move, face, position, direction, style, control);
 	PushStack(move);
@@ -151,7 +152,7 @@ PutMove(int face, int position, int direction, int style, int control)
 void
 GetMove(int *face, int *position, int *direction, int *style, int *control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	PopStack(&move);
 	ReadMove(face, position, direction, style, control, move);
@@ -166,7 +167,7 @@ MadeMoves(void)
 void
 FlushMoves(DinoWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	FlushStack();
 	for (face = 0; face < MAXFACES; face++)
@@ -186,13 +187,12 @@ NumMoves(void)
 void
 ScanMoves(FILE * fp, DinoWidget w, int moves)
 {
-	int         face, position, direction, style, control, k;
-	char        c;
+	int face, position, direction, style, control, k, c;
 
 	for (k = 0; k < moves; k++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d %d %d %d %d", &face, &position, &direction,
-			      &style, &control);
+			&style, &control);
 		MoveDino(w, face, position, direction, style, control);
 	}
 }
@@ -200,7 +200,7 @@ ScanMoves(FILE * fp, DinoWidget w, int moves)
 void
 PrintMoves(FILE * fp)
 {
-	int         face, position, direction, style, control, counter = 0;
+	int face, position, direction, style, control, counter = 0;
 
 	currMove = firstMove->next;
 	(void) fprintf(fp, "moves\tface\tpos\tdir\tstyle\tcon\n");
@@ -215,8 +215,7 @@ PrintMoves(FILE * fp)
 void
 ScanStartPosition(FILE * fp, DinoWidget w)
 {
-	int         face, position, num;
-	char        c;
+	int face, position, num, c;
 
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	for (face = 0; face < MAXFACES; face++)
@@ -233,7 +232,7 @@ ScanStartPosition(FILE * fp, DinoWidget w)
 void
 PrintStartPosition(FILE * fp, DinoWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	(void) fprintf(fp, "\nstartingPosition%c\n", SYMBOL);
 	for (face = 0; face < MAXFACES; face++) {
@@ -249,7 +248,7 @@ PrintStartPosition(FILE * fp, DinoWidget w)
 void
 SetStartPosition(DinoWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	for (face = 0; face < MAXFACES; face++)
 		for (position = 0; position < MAXORIENT; position++) {
@@ -258,5 +257,5 @@ SetStartPosition(DinoWidget w)
 				w->dino.cubeLoc[face][position].rotation =
 					startLoc[face][position].rotation;
 		}
-	DrawAllPolyhedrons(w);
+	DrawAllPieces(w);
 }
