@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -25,45 +25,37 @@
 
 /* Undo algorithm */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
 #include "MballP.h"
 
 typedef struct _MoveRecord {
-	/* int wedge, direction, control; */
-	unsigned short int packed;	/* This makes assumptions on the data. */
-	int         ring;	/* Do not make assumptions on this one. */
+#if 0
+	int wedge, direction, control;
+#endif
+	unsigned short int packed;  /* This makes assumptions on the data. */
+	int ring;		    /* Do not make assumptions on this one. */
 } MoveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord  move;
+	MoveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
 static MoveStack *currMove, *lastMove, *firstMove;
-static int  count;
-MballLoc   *startLoc[MAXWEDGES] =
+static int count;
+MballLoc  *startLoc[MAXWEDGES] =
 {
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL
 };
 
-static void InitStack(void);
-static void PushStack(MoveRecord move);
-static void PopStack(MoveRecord * move);
-static int  EmptyStack(void);
-static void FlushStack(void);
-
 static void
 InitStack(void)
 {
-	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
-	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	firstMove->previous = lastMove->next = NULL;
 	firstMove->next = lastMove;
 	lastMove->previous = firstMove;
@@ -73,8 +65,9 @@ InitStack(void)
 static void
 PushStack(MoveRecord move)
 {
-	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	lastMove->previous->next = currMove;
 	currMove->previous = lastMove->previous;
 	currMove->next = lastMove;
@@ -123,9 +116,12 @@ InitMoves(void)
 static void
 WriteMove(MoveRecord * move, int wedge, int ring, int direction, int control)
 {
-	/* move->wedge = wedge; move->direction = direction;
-	   move->control = control; */
-	move->packed = ((control & 0xF) << 8) + ((direction & 0xF) << 4) +
+#if 0
+	move->wedge = wedge;
+	move->direction = direction;
+	move->control = control;
+#endif
+	move->packed = ((direction & 0xFF) << 8) + ((control & 0xF) << 4) +
 		(wedge & 0xF);
 	move->ring = ring;
 }
@@ -133,18 +129,21 @@ WriteMove(MoveRecord * move, int wedge, int ring, int direction, int control)
 static void
 ReadMove(int *wedge, int *ring, int *direction, int *control, MoveRecord move)
 {
-	/* *wedge = move.wedge; *direction = move.direction;
-	   *control = move.control; */
-	*wedge = move.packed & 0xF;
-	*direction = (move.packed >> 4) & 0xF;
-	*control = (move.packed >> 8) & 0xF;
+#if 0
+	*wedge = move.wedge;
+	*direction = move.direction;
+	*control = move.control;
+#endif
+	*wedge = (int) (move.packed & 0xF);
+	*control = (int) ((move.packed >> 4) & 0xF);
+	*direction = (int) ((move.packed >> 8) & 0xFF);
 	*ring = move.ring;
 }
 
 void
 PutMove(int wedge, int ring, int direction, int control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	WriteMove(&move, wedge, ring, direction, control);
 	PushStack(move);
@@ -153,7 +152,7 @@ PutMove(int wedge, int ring, int direction, int control)
 void
 GetMove(int *wedge, int *ring, int *direction, int *control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	PopStack(&move);
 	ReadMove(wedge, ring, direction, control, move);
@@ -168,7 +167,7 @@ MadeMoves(void)
 void
 FlushMoves(MballWidget w)
 {
-	int         wedge, ring;
+	int wedge, ring;
 
 	FlushStack();
 	for (wedge = 0; wedge < w->mball.wedges; wedge++)
@@ -189,8 +188,7 @@ NumMoves(void)
 void
 ScanMoves(FILE * fp, MballWidget w, int moves)
 {
-	int         wedge, ring, direction, control, l;
-	char        c;
+	int wedge, ring, direction, control, l, c;
 
 	for (l = 0; l < moves; l++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
@@ -202,7 +200,7 @@ ScanMoves(FILE * fp, MballWidget w, int moves)
 void
 PrintMoves(FILE * fp)
 {
-	int         wedge, ring, direction, control, counter = 0;
+	int wedge, ring, direction, control, counter = 0;
 
 	currMove = firstMove->next;
 	(void) fprintf(fp, "moves\twedge\tring\tdir\tcon\n");
@@ -217,8 +215,7 @@ PrintMoves(FILE * fp)
 void
 ScanStartPosition(FILE * fp, MballWidget w)
 {
-	int         wedge, ring, num;
-	char        c;
+	int wedge, ring, num, c;
 
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	for (wedge = 0; wedge < w->mball.wedges; wedge++)
@@ -235,7 +232,7 @@ ScanStartPosition(FILE * fp, MballWidget w)
 void
 PrintStartPosition(FILE * fp, MballWidget w)
 {
-	int         wedge, ring;
+	int wedge, ring;
 
 	(void) fprintf(fp, "\nstartingPosition%c\n", SYMBOL);
 	for (wedge = 0; wedge < w->mball.wedges; wedge++) {
@@ -251,7 +248,7 @@ PrintStartPosition(FILE * fp, MballWidget w)
 void
 SetStartPosition(MballWidget w)
 {
-	int         wedge, ring;
+	int wedge, ring;
 
 	for (wedge = 0; wedge < w->mball.wedges; wedge++)
 		for (ring = 0; ring < w->mball.rings; ring++) {
