@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -25,43 +25,35 @@
 
 /* Undo algorithm */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
 #include "MlinkP.h"
 
 typedef struct _MoveRecord {
-	/* int direction, control; */
+#if 0
+	int direction, control;
+#endif
 	unsigned char packed;	/* This makes assumptions on the data. */
-	int         tile;	/* Do not make assumptions on this one. */
+	int tile;		/* Do not make assumptions on this one. */
 } MoveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord  move;
+	MoveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
 static MoveStack *currMove, *lastMove, *firstMove;
-static int  count;
-static int  startSpace;
-int        *startPosition = NULL;
-
-static void InitStack(void);
-static void PushStack(MoveRecord move);
-static void PopStack(MoveRecord * move);
-static int  EmptyStack(void);
-static void FlushStack(void);
+static int count;
+static int startSpace;
+int *startPosition = NULL;
 
 static void
 InitStack(void)
 {
-	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
-	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	firstMove->previous = lastMove->next = NULL;
 	firstMove->next = lastMove;
 	lastMove->previous = firstMove;
@@ -71,8 +63,9 @@ InitStack(void)
 static void
 PushStack(MoveRecord move)
 {
-	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	lastMove->previous->next = currMove;
 	currMove->previous = lastMove->previous;
 	currMove->next = lastMove;
@@ -88,7 +81,7 @@ PopStack(MoveRecord * move)
 	currMove = lastMove->previous;
 	lastMove->previous->previous->next = lastMove;
 	lastMove->previous = lastMove->previous->previous;
-	(void) free((void *) currMove);
+	free(currMove);
 	count--;
 }
 
@@ -105,7 +98,7 @@ FlushStack(void)
 		currMove = lastMove->previous;
 		lastMove->previous->previous->next = lastMove;
 		lastMove->previous = lastMove->previous->previous;
-		(void) free((void *) currMove);
+		free(currMove);
 	}
 	count = 0;
 }
@@ -121,7 +114,10 @@ InitMoves(void)
 static void
 WriteMove(MoveRecord * move, int direction, int tile, int control)
 {
-	/* move->direction = direction; move->control = control; */
+#if 0
+	move->direction = direction;
+	move->control = control;
+#endif
 	move->packed = ((control & 0xF) << 4) + (direction & 0xF);
 	move->tile = tile;
 }
@@ -129,16 +125,19 @@ WriteMove(MoveRecord * move, int direction, int tile, int control)
 static void
 ReadMove(int *direction, int *tile, int *control, MoveRecord move)
 {
-	/* *direction = move.direction; *control = move.control; */
-	*direction = move.packed & 0xF;
-	*control = (move.packed >> 4) & 0xF;
+#if 0
+	*direction = move.direction;
+	*control = move.control;
+#endif
+	*direction = (int) (move.packed & 0xF);
+	*control = (int) ((move.packed >> 4) & 0xF);
 	*tile = move.tile;
 }
 
 void
 PutMove(int direction, int tile, int control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	WriteMove(&move, direction, tile, control);
 	PushStack(move);
@@ -147,7 +146,7 @@ PutMove(int direction, int tile, int control)
 void
 GetMove(int *direction, int *tile, int *control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	PopStack(&move);
 	ReadMove(direction, tile, control, move);
@@ -162,7 +161,7 @@ MadeMoves(void)
 void
 FlushMoves(MlinkWidget w)
 {
-	int         i;
+	int i;
 
 	FlushStack();
 	startSpace = w->mlink.spacePosition;
@@ -180,30 +179,29 @@ NumMoves(void)
 void
 ScanMoves(FILE * fp, MlinkWidget w, int moves)
 {
-	int         direction, tile, shift, l;
-	char        c;
+	int direction, tile, shift, l, c;
 
 	for (l = 0; l < moves; l++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d %d %d", &direction, &tile, &shift);
-		if (!MoveMlink(w, direction, tile, shift))
-			(void) printf(
-					     "%d move in direction %d, tile %d, shift %d, can not be made.",
-					     l, direction, tile, shift);
+		if (!MoveMlink(w, direction, tile, shift, INSTANT))
+			(void) fprintf(stderr,
+				"%d move in direction %d, tile %d, shift %d, can not be made.\n",
+				l, direction, tile, shift);
 	}
 }
 
 void
 PrintMoves(FILE * fp)
 {
-	int         direction, tile, control, counter = 0;
+	int direction, tile, control, counter = 0;
 
 	currMove = firstMove->next;
 	(void) fprintf(fp, "moves\tdir\ttile\tshift\n");
 	while (currMove != lastMove) {
 		ReadMove(&direction, &tile, &control, currMove->move);
 		(void) fprintf(fp, "%d%c\t%d\t%d\t%d\n",
-			       ++counter, SYMBOL, direction, tile, control);
+			++counter, SYMBOL, direction, tile, control);
 		currMove = currMove->next;
 	}
 }
@@ -211,8 +209,7 @@ PrintMoves(FILE * fp)
 void
 ScanStartPosition(FILE * fp, MlinkWidget w)
 {
-	int         i, num;
-	char        c;
+	int i, num, c;
 
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	for (i = 0; i < w->mlink.tileFaces; i++) {
@@ -226,7 +223,7 @@ ScanStartPosition(FILE * fp, MlinkWidget w)
 void
 PrintStartPosition(FILE * fp, MlinkWidget w)
 {
-	int         i;
+	int i;
 
 	(void) fprintf(fp, "\nstartingPosition%c\n", SYMBOL);
 	for (i = 0; i < w->mlink.tileFaces; i++) {
@@ -240,10 +237,10 @@ PrintStartPosition(FILE * fp, MlinkWidget w)
 void
 SetStartPosition(MlinkWidget w)
 {
-	int         i;
+	int i;
 
 	w->mlink.spacePosition = startSpace;
 	for (i = 0; i < w->mlink.tileFaces; i++)
 		w->mlink.tileOfPosition[i] = startPosition[i];
-	DrawAllTiles(w, w->mlink.tileGC, w->mlink.borderGC);
+	DrawAllTiles(w);
 }
