@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -25,45 +25,37 @@
 
 /* Undo algorithm */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
 #include "OctP.h"
 
 typedef struct _MoveRecord {
-	/* int face, direction, style, control; */
-	unsigned short int packed;	/* This makes assumptions on the data. */
-	int         position;	/* Do not make assumptions on this one. */
+#if 0
+	int face, direction, style, control;
+#endif
+	unsigned short int packed;  /* This makes assumptions on the data. */
+	int position;		    /* Do not make assumptions on this one. */
 } MoveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord  move;
+	MoveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
 static MoveStack *currMove, *lastMove, *firstMove;
-static int  count;
-OctLoc     *startLoc[MAXFACES] =
+static int count;
+OctLoc *startLoc[MAXFACES] =
 {
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL
 };
 
-static void InitStack(void);
-static void PushStack(MoveRecord move);
-static void PopStack(MoveRecord * move);
-static int  EmptyStack(void);
-static void FlushStack(void);
-
 static void
 InitStack(void)
 {
-	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
-	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	firstMove->previous = lastMove->next = NULL;
 	firstMove->next = lastMove;
 	lastMove->previous = firstMove;
@@ -73,8 +65,9 @@ InitStack(void)
 static void
 PushStack(MoveRecord move)
 {
-	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	lastMove->previous->next = currMove;
 	currMove->previous = lastMove->previous;
 	currMove->next = lastMove;
@@ -123,8 +116,12 @@ InitMoves(void)
 static void
 WriteMove(MoveRecord * move, int face, int position, int direction, int style, int control)
 {
-	/* move->face = face; move->direction = direction; move->style = style;
-	   move->control = control; */
+#if 0
+	move->face = face;
+	move->direction = direction;
+	move->style = style;
+	move->control = control;
+#endif
 	move->packed = ((control & 0xF) << 12) + ((style & 0xF) << 8) +
 		((direction & 0xF) << 4) + (face & 0xF);
 	move->position = position;
@@ -133,19 +130,23 @@ WriteMove(MoveRecord * move, int face, int position, int direction, int style, i
 static void
 ReadMove(int *face, int *position, int *direction, int *style, int *control, MoveRecord move)
 {
-	/* *face = move.face; *direction = move.direction; *style = move.style;
-	   *control = move.control; */
-	*face = move.packed & 0xF;
-	*direction = (move.packed >> 4) & 0xF;
-	*style = (move.packed >> 8) & 0xF;
-	*control = (move.packed >> 12) & 0xF;
+#if 0
+	*face = move.face;
+	*direction = move.direction;
+	*style = move.style;
+	*control = move.control;
+#endif
+	*face = (int) (move.packed & 0xF);
+	*direction = (int) ((move.packed >> 4) & 0xF);
+	*style = (int) ((move.packed >> 8) & 0xF);
+	*control = (int) ((move.packed >> 12) & 0xF);
 	*position = move.position;
 }
 
 void
 PutMove(int face, int position, int direction, int style, int control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	WriteMove(&move, face, position, direction, style, control);
 	PushStack(move);
@@ -154,7 +155,7 @@ PutMove(int face, int position, int direction, int style, int control)
 void
 GetMove(int *face, int *position, int *direction, int *style, int *control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	PopStack(&move);
 	ReadMove(face, position, direction, style, control, move);
@@ -169,15 +170,15 @@ MadeMoves(void)
 void
 FlushMoves(OctWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	FlushStack();
 	for (face = 0; face < MAXFACES; face++)
 		for (position = 0; position < w->oct.sizeSize; position++) {
 			startLoc[face][position].face =
-				w->oct.octaLoc[face][position].face;
+				w->oct.facetLoc[face][position].face;
 			startLoc[face][position].rotation =
-				w->oct.octaLoc[face][position].rotation;
+				w->oct.facetLoc[face][position].rotation;
 		}
 }
 
@@ -190,13 +191,12 @@ NumMoves(void)
 void
 ScanMoves(FILE * fp, OctWidget w, int moves)
 {
-	int         face, position, direction, style, control, l;
-	char        c;
+	int face, position, direction, style, control, l, c;
 
 	for (l = 0; l < moves; l++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d %d %d %d %d",
-			      &face, &position, &direction, &style, &control);
+			&face, &position, &direction, &style, &control);
 		MoveOct(w, face, position, direction, style, control);
 	}
 }
@@ -204,7 +204,7 @@ ScanMoves(FILE * fp, OctWidget w, int moves)
 void
 PrintMoves(FILE * fp)
 {
-	int         face, position, direction, style, control, counter = 0;
+	int face, position, direction, style, control, counter = 0;
 
 	currMove = firstMove->next;
 	(void) fprintf(fp, "moves\tface\tpos\tdir\tstyle\tcon\n");
@@ -220,8 +220,7 @@ PrintMoves(FILE * fp)
 void
 ScanStartPosition(FILE * fp, OctWidget w)
 {
-	int         face, position, num;
-	char        c;
+	int face, position, num, c;
 
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	for (face = 0; face < MAXFACES; face++)
@@ -238,7 +237,7 @@ ScanStartPosition(FILE * fp, OctWidget w)
 void
 PrintStartPosition(FILE * fp, OctWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	(void) fprintf(fp, "\nstartingPosition%c\n", SYMBOL);
 	for (face = 0; face < MAXFACES; face++) {
@@ -254,15 +253,15 @@ PrintStartPosition(FILE * fp, OctWidget w)
 void
 SetStartPosition(OctWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	for (face = 0; face < MAXFACES; face++)
 		for (position = 0; position < w->oct.sizeSize; position++) {
-			w->oct.octaLoc[face][position].face =
+			w->oct.facetLoc[face][position].face =
 				startLoc[face][position].face;
 			if (w->oct.orient)
-				w->oct.octaLoc[face][position].rotation =
+				w->oct.facetLoc[face][position].rotation =
 					startLoc[face][position].rotation;
 		}
-	DrawAllPolyhedrons(w);
+	DrawAllPieces(w);
 }
