@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -36,10 +36,11 @@
 
 #include "Rubik.h"
 
-typedef struct _Rubik2DClassRec *Rubik2DWidgetClass;
 typedef struct _Rubik2DRec *Rubik2DWidget;
-
+#ifndef WINVER
+typedef struct _Rubik2DClassRec *Rubik2DWidgetClass;
 extern WidgetClass rubik2dWidgetClass;
+#endif
 
 #endif /* _XtRubik2d_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
