@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -30,26 +30,7 @@
 
 #include "Rubik2d.h"
 
-#define FRONTLOC 0
-#define BACKLOC 11
-#define COORD2D 8
-#define MAXX 3
-#define MAXY 4
-#define MAXXY 4			/* (MAX(MAXX,MAXY)) */
-#define MAXRECT (MAXX*MAXY)
-
-typedef struct _Rubik2DPart {
-	Position    cubeLength;
-	Position    faceLength;
-	Position    viewLength;
-} Rubik2DPart;
-
-typedef struct _Rubik2DRec {
-	CorePart    core;
-	RubikPart   rubik;
-	Rubik2DPart rubik2d;
-} Rubik2DRec;
-
+#ifndef WINVER
 /* This gets around C's inability to do inheritance */
 typedef struct _Rubik2DClassPart {
 	int         ignore;
@@ -62,9 +43,38 @@ typedef struct _Rubik2DClassRec {
 } Rubik2DClassRec;
 
 extern Rubik2DClassRec rubik2dClassRec;
+#endif
 
-extern int  SelectPolyhedrons2D(Rubik2DWidget w, int x, int y, int *face, int *position);
-extern int  NarrowSelection2D(Rubik2DWidget w, int *face, int *position, int *direction);
+#define FRONTLOC 0
+#define BACKLOC 11
+#define COORD2D 8
+#define MAXX 3
+#define MAXY 4
+#define MAXXY 4			/* (MAX(MAXX,MAXY)) */
+#define MAXRECT (MAXX*MAXY)
+
+typedef struct _Rubik2DPart {
+	Position    cubeLength;
+	Position    faceLengthx, faceLengthy, faceLengthz;
+	Position    viewLengthx, viewLengthy, viewLengthz;
+} Rubik2DPart;
+
+typedef struct _Rubik2DRec {
+	CorePart    core;
+	RubikPart   rubik;
+	Rubik2DPart rubik2d;
+} Rubik2DRec;
+
+extern Boolean SelectPieces2D(Rubik2DWidget w, int x, int y,
+	int *face, int *position);
+extern Boolean NarrowSelection2D(Rubik2DWidget w,
+	int *face, int *position, int *direction);
+extern void DrawFrame2D(Rubik2DWidget w, Boolean focus);
 extern void DrawSquare2D(Rubik2DWidget w, int face, int position, int offset);
+#ifdef WINVER
+extern void ResizeRubik2D(Rubik2DWidget w);
+extern void InitializeRubik2D(Rubik2DWidget w);
+extern void ExposeRubik2D(Rubik2DWidget w);
+#endif
 
 #endif /* _Rubik2dP_h */
