@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -30,34 +30,7 @@
 
 #include "Rubik3d.h"
 
-#define TR 8
-#define BR 9
-#define BL 10
-#define TL 11
-#define SAME 0
-#define OPPOSITE 1
-#define DOWN 0
-#define UP 1
-#define COORD3D 12
-#define MAXVIEWS 2
-#define MAXORIENT 4
-
-#define SQRT_3 1.732050808
-#define MULTIPLY(a) ((int)((double)a*SQRT_3/2.0))
-#define DIVIDE(a) ((int)((double)a*2.0/SQRT_3))
-
-typedef struct _Rubik3DPart {
-	Position    cubeDiagonal, cubeDiag, faceDiagonal;
-	XPoint      cubeSize, faceSize, viewSize;
-	XPoint      viewMiddle;
-} Rubik3DPart;
-
-typedef struct _Rubik3DRec {
-	CorePart    core;
-	RubikPart   rubik;
-	Rubik3DPart rubik3d;
-} Rubik3DRec;
-
+#ifndef WINVER
 /* This gets around C's inability to do inheritance */
 typedef struct _Rubik3DClassPart {
 	int         ignore;
@@ -70,9 +43,47 @@ typedef struct _Rubik3DClassRec {
 } Rubik3DClassRec;
 
 extern Rubik3DClassRec rubik3dClassRec;
+#endif
 
-extern int  SelectPolyhedrons3D(Rubik3DWidget w, int x, int y, int *face, int *position);
-extern int  NarrowSelection3D(Rubik3DWidget w, int *face, int *position, int *direction);
+#define TR 8
+#define BR 9
+#define BL 10
+#define TL 11
+#define SAME 0
+#define OPPOSITE 1
+#define DOWN 0
+#define UP 1
+#define COORD3D 12
+#define MAXVIEWS 2
+
+#define SQRT_3 1.732050808
+#define MULTIPLY(a) ((int)((double)a*SQRT_3/2.0))
+#define DIVIDE(a) ((int)((double)a*2.0/SQRT_3))
+
+typedef struct _Rubik3DPart {
+	Point       viewMiddle;
+	Point       faceSize, viewSize;
+	Point       cubeSizex, cubeSizey, cubeSizez;
+	Position    faceDiagonal;
+	Position    cubeDiagonalx, cubeDiagonaly, cubeDiagonalz;
+} Rubik3DPart;
+
+typedef struct _Rubik3DRec {
+	CorePart    core;
+	RubikPart   rubik;
+	Rubik3DPart rubik3d;
+} Rubik3DRec;
+
+extern Boolean SelectPieces3D(Rubik3DWidget w, int x, int y,
+	int *face, int *position);
+extern Boolean NarrowSelection3D(Rubik3DWidget w,
+	int *face, int *position, int *direction);
+extern void DrawFrame3D(Rubik3DWidget w, Boolean focus);
 extern void DrawSquare3D(Rubik3DWidget w, int face, int position, int offset);
+#ifdef WINVER
+extern void ResizeRubik3D(Rubik3DWidget w);
+extern void InitializeRubik3D(Rubik3DWidget w);
+extern void ExposeRubik3D(Rubik3DWidget w);
+#endif
 
 #endif /* _Rubik3dP_h */
