@@ -1,5 +1,4 @@
-
-/*- 
+/*-
 # X-BASED RUBIK'S CUBE(tm)
 #
 #  RubikS.c
@@ -10,8 +9,9 @@
 #  From cubist10.c-- for IBM PC.
 #  Used by permission.
 #  Taken from the algorithm in the Ideal Solution book.
+#  Break ability taken from the X puzzle by Don Bennett, HP Labs
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -29,39 +29,48 @@
 #
 */
 
+/* For break code */
+/* Puzzle - (C) Copyright 1987, 1988 Don Bennett.
+ *
+ * Permission to use, copy, modify, and distribute this software and its
+ * documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and that
+ * both that copyright notice and this permission notice appear in
+ * supporting documentation.
+ */
+
 /* Solver file for Rubik */
 
-#include <stdio.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
+#ifndef WINVER
+#define JMP
+#ifdef JMP
+#include <setjmp.h> /* longjmp ... interrupt */
+#endif
+#endif
 #include "RubikP.h"
-#include "Rubik2dP.h"
-#include "Rubik3dP.h"
 
 /* Mappings of Ideal notation to my General nxnxn cube notation */
-#define RotateLeft(w)	MoveRubik(w,2,0,LEFT,TRUE)
-#define RotateRight(w)	MoveRubik(w,2,0,RIGHT,TRUE)
-#define RotateUp(w)	MoveRubik(w,2,0,TOP,TRUE)
-#define RotateDown(w)	MoveRubik(w,2,0,BOTTOM,TRUE)
-#define RotateCw(w)	MoveRubik(w,0,0,RIGHT,TRUE)
-#define RotateCcw(w)	MoveRubik(w,0,0,LEFT,TRUE)
+#define RotateLeft(w)	MoveRubikPiece(w,2,0,LEFT,TRUE)
+#define RotateRight(w)	MoveRubikPiece(w,2,0,RIGHT,TRUE)
+#define RotateUp(w)	MoveRubikPiece(w,2,0,TOP,TRUE)
+#define RotateDown(w)	MoveRubikPiece(w,2,0,BOTTOM,TRUE)
+#define RotateCw(w)	MoveRubikPiece(w,0,0,RIGHT,TRUE)
+#define RotateCcw(w)	MoveRubikPiece(w,0,0,LEFT,TRUE)
 
-#define RotateTopLeft(w)	MoveRubik(w,2,0,LEFT,FALSE)
-#define RotateCenterLeft(w)	MoveRubik(w,2,w->rubik.size,LEFT,FALSE)
-#define RotateBottomLeft(w)	MoveRubik(w,2,w->rubik.size*(w->rubik.size-1),LEFT,FALSE)
-#define RotateTopRight(w)	MoveRubik(w,2,0,RIGHT,FALSE)
-#define RotateCenterRight(w)	MoveRubik(w,2,w->rubik.size,RIGHT,FALSE)
-#define RotateBottomRight(w)	MoveRubik(w,2,w->rubik.size*(w->rubik.size-1),RIGHT,FALSE)
-#define RotateLeftUp(w)		MoveRubik(w,2,0,TOP,FALSE)
-#define RotateCenterUp(w)	MoveRubik(w,2,1,TOP,FALSE)
-#define RotateRightUp(w)	MoveRubik(w,2,w->rubik.size-1,TOP,FALSE)
-#define RotateLeftDown(w)	MoveRubik(w,2,0,BOTTOM,FALSE)
-#define RotateCenterDown(w)	MoveRubik(w,2,1,BOTTOM,FALSE)
-#define RotateRightDown(w)	MoveRubik(w,2,w->rubik.size-1,BOTTOM,FALSE)
-#define RotateFrontCw(w)	MoveRubik(w,0,w->rubik.size*(w->rubik.size-1),RIGHT,FALSE)
-#define RotateFrontCcw(w)	MoveRubik(w,0,w->rubik.size*(w->rubik.size-1),LEFT,FALSE)
+#define RotateTopLeft(w)	MoveRubikPiece(w,2,0,LEFT,FALSE)
+#define RotateCenterLeft(w)	MoveRubikPiece(w,2,w->rubik.sizex,LEFT,FALSE)
+#define RotateBottomLeft(w)	MoveRubikPiece(w,2,w->rubik.sizex*(w->rubik.sizex-1),LEFT,FALSE)
+#define RotateTopRight(w)	MoveRubikPiece(w,2,0,RIGHT,FALSE)
+#define RotateCenterRight(w)	MoveRubikPiece(w,2,w->rubik.sizex,RIGHT,FALSE)
+#define RotateBottomRight(w)	MoveRubikPiece(w,2,w->rubik.sizex*(w->rubik.sizex-1),RIGHT,FALSE)
+#define RotateLeftUp(w)		MoveRubikPiece(w,2,0,TOP,FALSE)
+#define RotateCenterUp(w)	MoveRubikPiece(w,2,1,TOP,FALSE)
+#define RotateRightUp(w)	MoveRubikPiece(w,2,w->rubik.sizex-1,TOP,FALSE)
+#define RotateLeftDown(w)	MoveRubikPiece(w,2,0,BOTTOM,FALSE)
+#define RotateCenterDown(w)	MoveRubikPiece(w,2,1,BOTTOM,FALSE)
+#define RotateRightDown(w)	MoveRubikPiece(w,2,w->rubik.sizex-1,BOTTOM,FALSE)
+#define RotateFrontCw(w)	MoveRubikPiece(w,0,w->rubik.sizex*(w->rubik.sizex-1),RIGHT,FALSE)
+#define RotateFrontCcw(w)	MoveRubikPiece(w,0,w->rubik.sizex*(w->rubik.sizex-1),LEFT,FALSE)
 
 #define BLUE 0
 #define WHITE 1
@@ -78,21 +87,80 @@ static int  mapGeneralToIdeal[MAXFACES] =
 static int  mapIdealToGeneral[MAXFACES] =
 {2, 3, 5, 1, 0, 4};		/* Remember to subtract 1 */
 
-static int  Side(RubikWidget w, int m, int c);
-static int  FindCorner(RubikWidget w, int color1, int color2, int color3);
-static int  FindEdge(RubikWidget w, int color1, int color2);
-static void PlaceEdge(RubikWidget w, int edge, int top_color);
-static void SolveTop(RubikWidget w);
-static void AlignCorners(RubikWidget w);
-static void SwapBottomCorners(RubikWidget w);
-static void SolveBottom(RubikWidget w);
-static void Solve_2_2(RubikWidget w);
-static void SolveBottomEdges(RubikWidget w);
-static void AlignLastEdge(RubikWidget w);
-static void ColorAlignFront(RubikWidget w);
-static void AlignEdges(RubikWidget w);
-static void ShuffleEdges(RubikWidget w);
-static void RecolorTopEdges(RubikWidget w);
+static Boolean SolvingFlag = False;
+/* TODO Interruptability for Windows */
+#ifdef JMP
+static Boolean AbortSolvingFlag = False;
+static jmp_buf solve_env;
+
+static void
+AbortSolving(void)
+{
+	if (SolvingFlag)
+		AbortSolvingFlag = True;
+}
+
+static void
+ProcessButton(void /*XButtonEvent *event*/)
+{
+	AbortSolving();
+}
+
+static void
+ProcessVisibility(XVisibilityEvent *event)
+{
+	if (event->state != VisibilityUnobscured)
+		AbortSolving();
+}
+
+static void
+GetNextEvent(RubikWidget w, XEvent *event)
+{
+	if (!XCheckMaskEvent(XtDisplay(w), VisibilityChangeMask, event))
+		(void) XNextEvent(XtDisplay(w), event);
+}
+
+static void
+ProcessEvent(XEvent *event)
+{
+	switch(event->type) {
+		case KeyPress:
+		case ButtonPress:
+			ProcessButton(/*&event->xbutton*/);
+			break;
+		case VisibilityNotify:
+			ProcessVisibility(&event->xvisibility);
+			break;
+		default:
+			break;
+	}
+}
+
+static void
+ProcessEvents(RubikWidget w)
+{
+	XEvent event;
+
+	while(XPending(XtDisplay(w))) {
+		GetNextEvent(w, &event);
+		ProcessEvent(&event);
+	}
+}
+#endif
+
+static void
+MoveRubikPiece(RubikWidget w,
+	const int face, const int position, const int direction,
+	const int control)
+{
+#ifdef JMP
+	if (XPending(XtDisplay(w)))
+		ProcessEvents(w);
+	if (SolvingFlag && AbortSolvingFlag)
+		longjmp(solve_env, 1);
+#endif
+	MoveRubikDelay(w, face, position, direction, control);
+}
 
 static int
 Side(RubikWidget w, int m, int c)
@@ -103,10 +171,20 @@ Side(RubikWidget w, int m, int c)
 	i = c % 3;
 	j = c / 3;
 	if (i == 2)
-		i = w->rubik.size - 1;
+		i = w->rubik.sizex - 1;
 	if (j == 2)
-		j = w->rubik.size - 1;
-	return w->rubik.cubeLoc[d][j * w->rubik.size + i].face;
+		j = w->rubik.sizex - 1;
+	return w->rubik.cubeLoc[d][j * w->rubik.sizex + i].face;
+}
+
+static int
+Face(RubikWidget w, int m)
+{
+	int         d;
+
+	d = mapIdealToGeneral[m - 1];
+	return ((w->rubik.cubeLoc[d][4].rotation -
+		w->rubik.cubeLoc[d][0].rotation + MAXORIENT) % MAXORIENT);
 }
 
 /* This procedure finds the location of a specified corner.  An */
@@ -738,6 +816,21 @@ SolveTop(RubikWidget w)
 	RotateUp(w);		/* put the blue side to the back */
 }
 
+/* This procedure swaps the the bottom front corners. */
+static void
+SwapBottomCorners(RubikWidget w)
+{
+	RotateTopRight(w);
+	RotateFrontCw(w);
+	RotateTopLeft(w);
+	RotateLeftUp(w);
+	RotateTopLeft(w);
+	RotateLeftDown(w);
+	RotateTopRight(w);
+	RotateFrontCw(w);
+	RotateFrontCw(w);
+}
+
 /* This procedure places the front (GREEN) four corners into */
 /* their correct positions. */
 static void
@@ -774,19 +867,82 @@ AlignCorners(RubikWidget w)
 	}
 }
 
-/* This procedure swaps the the bottom front corners. */
+/* This procedure aligns the bottom corner colors (may need to be repeated). */
 static void
-SwapBottomCorners(RubikWidget w)
+ColorAlignFront(RubikWidget w)
 {
 	RotateTopRight(w);
 	RotateFrontCw(w);
+	RotateFrontCw(w);
 	RotateTopLeft(w);
-	RotateLeftUp(w);
-	RotateTopLeft(w);
-	RotateLeftDown(w);
+	RotateFrontCw(w);
 	RotateTopRight(w);
 	RotateFrontCw(w);
+	RotateTopLeft(w);
 	RotateFrontCw(w);
+	RotateFrontCw(w);
+}
+
+/* This procedure moves the remaining BLUE edge piece into position */
+/* from edge position #6. */
+static void
+AlignLastEdge(RubikWidget w)
+{
+	/* edge piece should be in edge position #6 */
+	/* check its orientation and decide which sequence to perform */
+	if (Side(w, 1, 5) == BLUE) {
+		RotateCenterLeft(w);
+		RotateFrontCw(w);
+		RotateCenterRight(w);
+		RotateFrontCcw(w);
+		RotateCenterLeft(w);
+		RotateFrontCcw(w);
+		RotateCenterRight(w);
+		RotateFrontCw(w);
+	} else {
+		RotateFrontCcw(w);
+		RotateCenterLeft(w);
+		RotateFrontCw(w);
+		RotateCenterRight(w);
+		RotateFrontCw(w);
+		RotateCenterLeft(w);
+		RotateFrontCcw(w);
+	}
+}
+
+/* This procedure "shuffles" the three center edges on the front and */
+/* top faces. */
+static void
+ShuffleEdges(RubikWidget w)
+{
+	RotateCenterUp(w);
+	RotateTopRight(w);
+	RotateTopRight(w);
+	RotateCenterDown(w);
+	RotateTopRight(w);
+	RotateTopRight(w);
+}
+
+/* This procedure should be used when the two opposing top front and back */
+/* edge pieces are in position but not color aligned (this sequence is */
+/* known as Rubik's Maneuver). */
+static void
+RecolorTopEdges(RubikWidget w)
+{
+	RotateCenterUp(w);
+	RotateTopRight(w);
+	RotateCenterUp(w);
+	RotateTopRight(w);
+	RotateCenterUp(w);
+	RotateTopRight(w);
+	RotateTopRight(w);
+	RotateCenterDown(w);
+	RotateTopRight(w);
+	RotateCenterDown(w);
+	RotateTopRight(w);
+	RotateCenterDown(w);
+	RotateTopRight(w);
+	RotateTopRight(w);
 }
 
 /* This procedure completes the GREEN side by color-aligning the GREEN */
@@ -842,7 +998,7 @@ Solve_2_2(RubikWidget w)
 	int         i;
 
 	for (i = 0; i < 3; i++)	/* This is not always efficient */
-		if (!CheckSolved(w))
+		if (!CheckSolved(w, False))
 			RotateFrontCw(w);
 }
 
@@ -903,49 +1059,6 @@ SolveBottomEdges(RubikWidget w)
 	}
 }
 
-/* This procedure moves the remaining BLUE edge piece into position */
-/* from edge position #6. */
-static void
-AlignLastEdge(RubikWidget w)
-{
-	/* edge piece should be in edge position #6 */
-	/* check its orientation and decide which sequence to perform */
-	if (Side(w, 1, 5) == BLUE) {
-		RotateCenterLeft(w);
-		RotateFrontCw(w);
-		RotateCenterRight(w);
-		RotateFrontCcw(w);
-		RotateCenterLeft(w);
-		RotateFrontCcw(w);
-		RotateCenterRight(w);
-		RotateFrontCw(w);
-	} else {
-		RotateFrontCcw(w);
-		RotateCenterLeft(w);
-		RotateFrontCw(w);
-		RotateCenterRight(w);
-		RotateFrontCw(w);
-		RotateCenterLeft(w);
-		RotateFrontCcw(w);
-	}
-}
-
-/* This procedure aligns the bottom corner colors (may need to be repeated). */
-static void
-ColorAlignFront(RubikWidget w)
-{
-	RotateTopRight(w);
-	RotateFrontCw(w);
-	RotateFrontCw(w);
-	RotateTopLeft(w);
-	RotateFrontCw(w);
-	RotateTopRight(w);
-	RotateFrontCw(w);
-	RotateTopLeft(w);
-	RotateFrontCw(w);
-	RotateFrontCw(w);
-}
-
 /* This procedure completes the solution process by placing the */
 /* remaining edges in place and alignment. */
 static void
@@ -982,7 +1095,7 @@ AlignEdges(RubikWidget w)
 	} else if (edge == 12)
 		RotateBottomRight(w);
 
-	if (CheckSolved(w))
+	if (CheckSolved(w, False))
 		return;
 
 	RotateCcw(w);		/* place unaligned edges vertically */
@@ -1062,66 +1175,193 @@ AlignEdges(RubikWidget w)
 		if (Side(w, 1, 7) != Side(w, 1, 4))
 			RotateUp(w);
 		RecolorTopEdges(w);
-		if (!CheckSolved(w)) {
+		if (!CheckSolved(w, False)) {
 			RotateDown(w);
 			RecolorTopEdges(w);
 		}
 	}
 }
 
-/* This procedure "shuffles" the three center edges on the front and */
-/* top faces. */
+/* Wrong center rotation on top and front */
 static void
-ShuffleEdges(RubikWidget w)
+Shuffle2_180(RubikWidget w)
 {
-	RotateCenterUp(w);
-	RotateTopRight(w);
-	RotateTopRight(w);
-	RotateCenterDown(w);
-	RotateTopRight(w);
-	RotateTopRight(w);
+	int i;
+
+	for (i = 0; i < 3; i++)
+		ShuffleEdges(w);
 }
 
-/* This procedure should be used when the two opposing top front and back */
-/* edge pieces are in position but not color aligned (this sequence is */
-/* known as Rubik's Maneuver). */
+/* Wrong center rotation on top */
 static void
-RecolorTopEdges(RubikWidget w)
+Shuffle1_180(RubikWidget w, Boolean Top)
 {
-	RotateCenterUp(w);
-	RotateTopRight(w);
-	RotateCenterUp(w);
-	RotateTopRight(w);
-	RotateCenterUp(w);
-	RotateTopRight(w);
-	RotateTopRight(w);
-	RotateCenterDown(w);
-	RotateTopRight(w);
-	RotateCenterDown(w);
-	RotateTopRight(w);
-	RotateCenterDown(w);
-	RotateTopRight(w);
-	RotateTopRight(w);
+	int i;
+
+	if (Top) {
+		for (i = 0; i < 30; i++) {
+			RotateTopRight(w);
+			RotateFrontCw(w);
+			RotateFrontCw(w);
+		}
+	} else {
+		for (i = 0; i < 30; i++) {
+			RotateTopRight(w);
+			RotateTopRight(w);
+			RotateFrontCw(w);
+		}
+	}
+}
+
+/* Pairs off by 90 degrees */
+static void
+Shuffle2_90(RubikWidget w, Boolean CounterTop, Boolean CounterFront)
+{
+	int i, num;
+
+	num = ((CounterTop && !CounterFront) || (!CounterTop && CounterFront)) ?
+		63 : 105;
+	for (i = 0; i < num; i++) {
+		if (CounterFront)
+			RotateFrontCcw(w);
+		else
+			RotateFrontCw(w);
+		if (CounterTop)
+			RotateTopRight(w);
+		else
+			RotateTopLeft(w);
+	}
+}
+
+static void
+SolveAdjCenters(RubikWidget w)
+{
+	int face0 = Face(w, 5), face1 = Face(w, 1);
+
+	if ((face0 == 2 && face1 != 0) ||
+	    (face1 == 2 && face0 != 0)) {
+		Shuffle2_180(w);
+	} else if (face0 == 2 && face1 == 0) {
+		Shuffle1_180(w, True);
+	} else if (face0 == 0 && face1 == 2) {
+		Shuffle1_180(w, False);
+	} else if (face0 == 1 && face1 == 1) {
+		Shuffle2_90(w, True, True);
+	} else if (face0 == 3 && face1 == 1) {
+		Shuffle2_90(w, True, False);
+	} else if (face0 == 1 && face1 == 3) {
+		Shuffle2_90(w, False, True);
+	} else if (face0 == 3 && face1 == 3) {
+		Shuffle2_90(w, False, False);
+	}
+}
+
+static void
+SolveOppCenters(RubikWidget w)
+{
+	int face0, face1, face2;
+	Boolean fixOp = False;
+
+	face0 = Face(w, 5);
+	face1 = Face(w, 1);
+	face2 = Face(w, 4);
+	if ((face1 == 1) || (face1 == 3)) {
+		RotateUp(w);
+		fixOp = True;
+	} else if ((face2 == 1) || (face2 == 3)) {
+		RotateCw(w);
+		fixOp = True;
+	} else if ((face0 == 1) || (face0 == 3))
+		fixOp = True;
+	if (!fixOp)
+		return;
+	face0 = Face(w, 5);
+	face1 = Face(w, 1);
+	if (face0 == 1)
+		Shuffle2_90(w, False, True);
+	else /* face0 == 3 */
+		Shuffle2_90(w, True, False);
+	RotateUp(w);
+	face0 = Face(w, 5);
+	face1 = Face(w, 1);
+	if (face0 == 1 && face1 == 1) {
+		Shuffle2_90(w, True, True);
+	} else if (face0 == 3 && face1 == 1) {
+		Shuffle2_90(w, True, False);
+	} else if (face0 == 1 && face1 == 3) {
+		Shuffle2_90(w, False, True);
+	} else if (face0 == 3 && face1 == 3) {
+		Shuffle2_90(w, False, False);
+	}
+}
+
+static void
+SolveCenters(RubikWidget w)
+{
+	SolveAdjCenters(w); /* 5-1 */
+	RotateUp(w);
+	RotateUp(w);
+	SolveAdjCenters(w); /* 6-3 */
+	RotateCw(w);
+	SolveAdjCenters(w); /* 4-3 */
+	RotateUp(w);
+	SolveAdjCenters(w); /* 3-2 */
+	/* only 90 degree matches left */
+	RotateUp(w);
+	SolveAdjCenters(w); /* 2-1 */
+	RotateUp(w);
+	SolveAdjCenters(w); /* 1-4 */
+	RotateCcw(w);
+	SolveAdjCenters(w); /* 5-4 */
+	RotateUp(w);
+	SolveAdjCenters(w); /* 4-6 */
+	RotateUp(w);
+	SolveAdjCenters(w); /* 6-2 */
+	RotateUp(w);
+	SolveAdjCenters(w); /* 2-5 */
+	RotateCcw(w);
+	RotateUp(w);
+	SolveAdjCenters(w); /* 1-6 */
+	RotateUp(w);
+	RotateUp(w);
+	SolveAdjCenters(w); /* 3-5 */
+	/* only 1 90 degree matches left possible on opposite sides */
+	SolveOppCenters(w);
 }
 
 /* This procedure coordinates the solution process. */
 void
-SolvePolyhedrons(RubikWidget w)
+SolveSomePieces(RubikWidget w)
 {
-	rubikCallbackStruct cb;
+	SetRubik(w, RUBIK_RESET);
+	if (SolvingFlag)
+		return;
+#ifdef JMP
+	if (!setjmp(solve_env))
+#endif
+	{
+		SolvingFlag = True;
 
-	cb.reason = RUBIK_RESET;
-	XtCallCallbacks((Widget) w, XtNselectCallback, &cb);
-	if (!CheckSolved(w)) {
-		SolveTop(w);
-		AlignCorners(w);
-		SolveBottom(w);
-		if (w->rubik.size > 2) {
-			SolveBottomEdges(w);
-			AlignEdges(w);
-		} else if (w->rubik.size == 2)
-			Solve_2_2(w);
+		if (!CheckSolved(w, w->rubik.orient)) {
+			SolveTop(w);
+			AlignCorners(w);
+			SolveBottom(w);
+			if (w->rubik.sizex > 2) {
+				SolveBottomEdges(w);
+				AlignEdges(w);
+				if (w->rubik.orient)
+					SolveCenters(w);
+			} else if (w->rubik.sizex == 2)
+				Solve_2_2(w);
+		}
 	}
-	cb.reason = RUBIK_COMPUTED;
-	XtCallCallbacks((Widget) w, XtNselectCallback, &cb);
+#ifdef JMP
+	else {
+		DrawAllPieces(w);
+	}
+	AbortSolvingFlag = False;
+#endif
+	SolvingFlag = False;
+	w->rubik.cheat = True; /* Assume the worst. */
+	SetRubik(w, RUBIK_COMPUTED);
 }
