@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -25,47 +25,37 @@
 
 /* Undo algorithm */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
 #include "RubikP.h"
-#include "Rubik2dP.h"
-#include "Rubik3dP.h"
 
 typedef struct _MoveRecord {
-	/* int face, direction, control; */
-	unsigned short int packed;	/* This makes assumptions on the data. */
-	int         position;	/* Do not make assumptions on this one. */
+#if 0
+	int face, direction, control;
+#endif
+	unsigned short int packed;  /* This makes assumptions on the data. */
+	int position;		    /* Do not make assumptions on this one. */
 } MoveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord  move;
+	MoveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
 static MoveStack *currMove, *lastMove, *firstMove;
-static int  count;
-RubikLoc   *startLoc[MAXFACES] =
+static int count;
+RubikLoc  *startLoc[MAXFACES] =
 {
 	NULL, NULL, NULL, NULL, NULL, NULL
 };
 
-static void InitStack(void);
-static void PushStack(MoveRecord move);
-static void PopStack(MoveRecord * move);
-static int  EmptyStack(void);
-static void FlushStack(void);
-
 static void
 InitStack(void)
 {
-	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
-	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	firstMove->previous = lastMove->next = NULL;
 	firstMove->next = lastMove;
 	lastMove->previous = firstMove;
@@ -75,8 +65,9 @@ InitStack(void)
 static void
 PushStack(MoveRecord move)
 {
-	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	lastMove->previous->next = currMove;
 	currMove->previous = lastMove->previous;
 	currMove->next = lastMove;
@@ -125,8 +116,11 @@ InitMoves(void)
 static void
 WriteMove(MoveRecord * move, int face, int position, int direction, int control)
 {
-	/* move->face = face; move->direction = direction;
-	   move->control = control; */
+#if 0
+	move->face = face;
+	move->direction = direction;
+	move->control = control;
+#endif
 	move->packed = ((control & 0xF) << 8) + ((direction & 0xF) << 4) +
 		(face & 0xF);
 	move->position = position;
@@ -135,18 +129,21 @@ WriteMove(MoveRecord * move, int face, int position, int direction, int control)
 static void
 ReadMove(int *face, int *position, int *direction, int *control, MoveRecord move)
 {
-	/* *face = move.face; *direction = move.direction;
-	   *control = move.control; */
-	*face = move.packed & 0xF;
-	*direction = (move.packed >> 4) & 0xF;
-	*control = (move.packed >> 8) & 0xF;
+#if 0
+	*face = move.face;
+	*direction = move.direction;
+	*control = move.control;
+#endif
+	*face = (int) (move.packed & 0xF);
+	*direction = (int) ((move.packed >> 4) & 0xF);
+	*control = (int) ((move.packed >> 8) & 0xF);
 	*position = move.position;
 }
 
 void
 PutMove(int face, int position, int direction, int control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	WriteMove(&move, face, position, direction, control);
 	PushStack(move);
@@ -155,7 +152,7 @@ PutMove(int face, int position, int direction, int control)
 void
 GetMove(int *face, int *position, int *direction, int *control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	PopStack(&move);
 	ReadMove(face, position, direction, control, move);
@@ -170,11 +167,11 @@ MadeMoves(void)
 void
 FlushMoves(RubikWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	FlushStack();
 	for (face = 0; face < MAXFACES; face++)
-		for (position = 0; position < w->rubik.sizeSize; position++) {
+		for (position = 0; position < sizeFace(w, face); position++) {
 			startLoc[face][position].face =
 				w->rubik.cubeLoc[face][position].face;
 			startLoc[face][position].rotation =
@@ -191,27 +188,26 @@ NumMoves(void)
 void
 ScanMoves(FILE * fp, RubikWidget w, int moves)
 {
-	int         face, position, direction, control, k;
-	char        c;
+	int face, position, direction, control, k, c;
 
 	for (k = 0; k < moves; k++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d %d %d %d", &face, &position, &direction, &control);
-		MoveRubik(w, face, position, direction, control);
+		MoveRubik(w, face, position, direction, control, INSTANT);
 	}
 }
 
 void
 PrintMoves(FILE * fp)
 {
-	int         face, position, direction, control, counter = 0;
+	int face, position, direction, control, counter = 0;
 
 	currMove = firstMove->next;
 	(void) fprintf(fp, "moves\tface\tpos\tdir\tcon\n");
 	while (currMove != lastMove) {
 		ReadMove(&face, &position, &direction, &control, currMove->move);
 		(void) fprintf(fp, "%d%c\t%d\t%d\t%d\t%d\n",
-		      ++counter, SYMBOL, face, position, direction, control);
+			++counter, SYMBOL, face, position, direction, control);
 		currMove = currMove->next;
 	}
 }
@@ -219,12 +215,11 @@ PrintMoves(FILE * fp)
 void
 ScanStartPosition(FILE * fp, RubikWidget w)
 {
-	int         face, position, num;
-	char        c;
+	int face, position, num, c;
 
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	for (face = 0; face < MAXFACES; face++)
-		for (position = 0; position < w->rubik.sizeSize; position++) {
+		for (position = 0; position < sizeFace(w, face); position++) {
 			(void) fscanf(fp, "%d ", &num);
 			startLoc[face][position].face = num;
 			if (w->rubik.orient) {
@@ -237,14 +232,15 @@ ScanStartPosition(FILE * fp, RubikWidget w)
 void
 PrintStartPosition(FILE * fp, RubikWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	(void) fprintf(fp, "\nstartingPosition%c\n", SYMBOL);
 	for (face = 0; face < MAXFACES; face++) {
-		for (position = 0; position < w->rubik.sizeSize; position++) {
+		for (position = 0; position < sizeFace(w, face); position++) {
 			(void) fprintf(fp, "%d ", startLoc[face][position].face);
 			if (w->rubik.orient)
-				(void) fprintf(fp, "%d  ", startLoc[face][position].rotation);
+				(void) fprintf(fp, "%d  ",
+					startLoc[face][position].rotation);
 		}
 		(void) fprintf(fp, "\n");
 	}
@@ -253,15 +249,15 @@ PrintStartPosition(FILE * fp, RubikWidget w)
 void
 SetStartPosition(RubikWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	for (face = 0; face < MAXFACES; face++)
-		for (position = 0; position < w->rubik.sizeSize; position++) {
+		for (position = 0; position < sizeFace(w, face); position++) {
 			w->rubik.cubeLoc[face][position].face =
 				startLoc[face][position].face;
 			if (w->rubik.orient)
 				w->rubik.cubeLoc[face][position].rotation =
 					startLoc[face][position].rotation;
 		}
-	DrawAllPolyhedrons(w);
+	DrawAllPieces(w);
 }
