@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -30,26 +30,7 @@
 
 #include "Skewb2d.h"
 
-#define FRONTLOC 0
-#define BACKLOC 11
-#define COORD2D 8
-#define MAXX 3
-#define MAXY 4
-#define MAXXY 4			/* (MAX(MAXX,MAXY)) */
-#define MAXRECT (MAXX*MAXY)
-
-typedef struct _Skewb2DPart {
-	Position    diamondLength;
-	Position    faceLength;
-	Position    viewLength;
-} Skewb2DPart;
-
-typedef struct _Skewb2DRec {
-	CorePart    core;
-	SkewbPart   skewb;
-	Skewb2DPart skewb2d;
-} Skewb2DRec;
-
+#ifndef WINVER
 /* This gets around C's inability to do inheritance */
 typedef struct _Skewb2DClassPart {
 	int         ignore;
@@ -62,10 +43,40 @@ typedef struct _Skewb2DClassRec {
 } Skewb2DClassRec;
 
 extern Skewb2DClassRec skewb2dClassRec;
+#endif
 
-extern int  SelectPolyhedrons2D(Skewb2DWidget w, int x, int y, int *face, int *position);
-extern int  NarrowSelection2D(Skewb2DWidget w, int *face, int *position, int *direction);
-extern void DrawDiamond2D(Skewb2DWidget w, int face);
-extern void DrawTriangle2D(Skewb2DWidget w, int face, int position, int offset);
+#define FRONTLOC 0
+#define BACKLOC 11
+#define COORD2D 8
+#define MAXX 3
+#define MAXY 4
+#define MAXXY 4			/* (MAX(MAXX,MAXY)) */
+#define MAXRECT (MAXX*MAXY)
+
+typedef struct _Skewb2DPart {
+	Position    faceLength;
+	Position    viewLength;
+	Position    diamondLength;
+} Skewb2DPart;
+
+typedef struct _Skewb2DRec {
+	CorePart    core;
+	SkewbPart   skewb;
+	Skewb2DPart skewb2d;
+} Skewb2DRec;
+
+extern Boolean SelectPieces2D(Skewb2DWidget w, int x, int y,
+	int *face, int *position);
+extern Boolean NarrowSelection2D(Skewb2DWidget w,
+	int *face, int *position, int *direction);
+extern void DrawFrame2D(Skewb2DWidget w, Boolean focus);
+extern void DrawDiamond2D(Skewb2DWidget w, int face, int offset);
+extern void DrawTriangle2D(Skewb2DWidget w, int face, int position,
+	int offset);
+#ifdef WINVER
+extern void ResizeSkewb2D(Skewb2DWidget w);
+extern void InitializeSkewb2D(Skewb2DWidget w);
+extern void ExposeSkewb2D(Skewb2DWidget w);
+#endif
 
 #endif /* _Skewb2dP_h */
