@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -36,10 +36,11 @@
 
 #include "Skewb.h"
 
-typedef struct _Skewb3DClassRec *Skewb3DWidgetClass;
 typedef struct _Skewb3DRec *Skewb3DWidget;
-
+#ifndef WINVER
+typedef struct _Skewb3DClassRec *Skewb3DWidgetClass;
 extern WidgetClass skewb3dWidgetClass;
+#endif
 
 #endif /* _XtSkewb3d_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
