@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -30,6 +30,21 @@
 
 #include "Skewb3d.h"
 
+#ifndef WINVER
+/* This gets around C's inability to do inheritance */
+typedef struct _Skewb3DClassPart {
+	int         ignore;
+} Skewb3DClassPart;
+
+typedef struct _Skewb3DClassRec {
+	CoreClassPart core_class;
+	SkewbClassPart skewb_class;
+	Skewb3DClassPart skewb3d_class;
+} Skewb3DClassRec;
+
+extern Skewb3DClassRec skewb3dClassRec;
+#endif
+
 #define SAME 0
 #define OPPOSITE 1
 #define DOWN 0
@@ -43,8 +58,8 @@
 
 typedef struct _Skewb3DPart {
 	Position    cubeDiagonal, cubeDiag, diamondDiagonal, faceDiagonal;
-	XPoint      cubeSize, diamondSize, faceSize, viewSize;
-	XPoint      viewMiddle;
+	Point       cubeSize, diamondSize, faceSize, viewSize;
+	Point       viewMiddle;
 } Skewb3DPart;
 
 typedef struct _Skewb3DRec {
@@ -53,22 +68,18 @@ typedef struct _Skewb3DRec {
 	Skewb3DPart skewb3d;
 } Skewb3DRec;
 
-/* This gets around C's inability to do inheritance */
-typedef struct _Skewb3DClassPart {
-	int         ignore;
-} Skewb3DClassPart;
-
-typedef struct _Skewb3DClassRec {
-	CoreClassPart core_class;
-	SkewbClassPart skewb_class;
-	Skewb3DClassPart skewb3d_class;
-} Skewb3DClassRec;
-
-extern Skewb3DClassRec skewb3dClassRec;
-
-extern int  SelectPolyhedrons3D(Skewb3DWidget w, int x, int y, int *face, int *position);
-extern int  NarrowSelection3D(Skewb3DWidget w, int *face, int *position, int *direction);
-extern void DrawDiamond3D(Skewb3DWidget w, int face);
-extern void DrawTriangle3D(Skewb3DWidget w, int face, int position, int offset);
+extern Boolean SelectPieces3D(Skewb3DWidget w, int x, int y,
+	int *face, int *position);
+extern Boolean NarrowSelection3D(Skewb3DWidget w,
+	int *face, int *position, int *direction);
+extern void DrawFrame3D(Skewb3DWidget w, Boolean focus);
+extern void DrawDiamond3D(Skewb3DWidget w, int face, int offset);
+extern void DrawTriangle3D(Skewb3DWidget w, int face, int position,
+	int offset);
+#ifdef WINVER
+extern void ResizeSkewb3D(Skewb3DWidget w);
+extern void InitializeSkewb3D(Skewb3DWidget w);
+extern void ExposeSkewb3D(Skewb3DWidget w);
+#endif
 
 #endif /* _Skewb3dP_h */
