@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -25,43 +25,33 @@
 
 /* Undo algorithm */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
 #include "SkewbP.h"
-#include "Skewb2dP.h"
-#include "Skewb3dP.h"
 
 typedef struct _MoveRecord {
-	/* int face, position, direction, control; */
+#if 0
+	int face, position, direction, control;
+#endif
 	unsigned short int packed;	/* This makes assumptions on the data. */
 } MoveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord  move;
+	MoveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
 static MoveStack *currMove, *lastMove, *firstMove;
-static int  count;
+static int count;
 static SkewbLoc startLoc[MAXFACES][MAXCUBES];
 
-static void InitStack(void);
-static void PushStack(MoveRecord move);
-static void PopStack(MoveRecord * move);
-static int  EmptyStack(void);
-static void FlushStack(void);
-
 static void
 InitStack(void)
 {
-	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
-	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	firstMove->previous = lastMove->next = NULL;
 	firstMove->next = lastMove;
 	lastMove->previous = firstMove;
@@ -71,8 +61,9 @@ InitStack(void)
 static void
 PushStack(MoveRecord move)
 {
-	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	lastMove->previous->next = currMove;
 	currMove->previous = lastMove->previous;
 	currMove->next = lastMove;
@@ -121,8 +112,12 @@ InitMoves(void)
 static void
 WriteMove(MoveRecord * move, int face, int position, int direction, int control)
 {
-	/* move.face = face; move.position = position;
-	   move.direction = direction; move.control = control; */
+#if 0
+	move.face = face;
+	move.position = position;
+	move.direction = direction;
+	move.control = control;
+#endif
 	move->packed = ((control & 0xF) << 12) + ((direction & 0xF) << 8) +
 		((position & 0xF) << 4) + (face & 0xF);
 }
@@ -130,18 +125,22 @@ WriteMove(MoveRecord * move, int face, int position, int direction, int control)
 static void
 ReadMove(int *face, int *position, int *direction, int *control, MoveRecord move)
 {
-	/* *face = move->face; *position = move->position;
-	   *direction = move.direction; *control = move.control; */
-	*face = move.packed & 0xF;
-	*position = (move.packed >> 4) & 0xF;
-	*direction = (move.packed >> 8) & 0xF;
-	*control = (move.packed >> 12) & 0xF;
+#if 0
+	*face = move->face;
+	*position = move->position;
+	*direction = move.direction;
+	*control = move.control;
+#endif
+	*face = (int) (move.packed & 0xF);
+	*position = (int) ((move.packed >> 4) & 0xF);
+	*direction = (int) ((move.packed >> 8) & 0xF);
+	*control = (int) ((move.packed >> 12) & 0xF);
 }
 
 void
 PutMove(int face, int position, int direction, int control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	WriteMove(&move, face, position, direction, control);
 	PushStack(move);
@@ -150,7 +149,7 @@ PutMove(int face, int position, int direction, int control)
 void
 GetMove(int *face, int *position, int *direction, int *control)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	PopStack(&move);
 	ReadMove(face, position, direction, control, move);
@@ -165,7 +164,7 @@ MadeMoves(void)
 void
 FlushMoves(SkewbWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	FlushStack();
 	for (face = 0; face < MAXFACES; face++)
@@ -185,8 +184,7 @@ NumMoves(void)
 void
 ScanMoves(FILE * fp, SkewbWidget w, int moves)
 {
-	int         face, position, direction, control, k;
-	char        c;
+	int face, position, direction, control, k, c;
 
 	for (k = 0; k < moves; k++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
@@ -198,14 +196,14 @@ ScanMoves(FILE * fp, SkewbWidget w, int moves)
 void
 PrintMoves(FILE * fp)
 {
-	int         face, position, direction, control, counter = 0;
+	int face, position, direction, control, counter = 0;
 
 	currMove = firstMove->next;
 	(void) fprintf(fp, "moves\tface\tpos\tdir\tcon\n");
 	while (currMove != lastMove) {
 		ReadMove(&face, &position, &direction, &control, currMove->move);
 		(void) fprintf(fp, "%d%c\t%d\t%d\t%d\t%d\n",
-		      ++counter, SYMBOL, face, position, direction, control);
+			++counter, SYMBOL, face, position, direction, control);
 		currMove = currMove->next;
 	}
 }
@@ -213,8 +211,7 @@ PrintMoves(FILE * fp)
 void
 ScanStartPosition(FILE * fp, SkewbWidget w)
 {
-	int         face, position, num;
-	char        c;
+	int face, position, num, c;
 
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	for (face = 0; face < MAXFACES; face++)
@@ -231,14 +228,15 @@ ScanStartPosition(FILE * fp, SkewbWidget w)
 void
 PrintStartPosition(FILE * fp, SkewbWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	(void) fprintf(fp, "\nstartingPosition%c\n", SYMBOL);
 	for (face = 0; face < MAXFACES; face++) {
 		for (position = 0; position < MAXCUBES; position++) {
 			(void) fprintf(fp, "%d ", startLoc[face][position].face);
 			if (w->skewb.orient)
-				(void) fprintf(fp, "%d  ", startLoc[face][position].rotation);
+				(void) fprintf(fp, "%d  ",
+					startLoc[face][position].rotation);
 		}
 		(void) fprintf(fp, "\n");
 	}
@@ -247,7 +245,7 @@ PrintStartPosition(FILE * fp, SkewbWidget w)
 void
 SetStartPosition(SkewbWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	for (face = 0; face < MAXFACES; face++)
 		for (position = 0; position < MAXCUBES; position++) {
@@ -256,5 +254,5 @@ SetStartPosition(SkewbWidget w)
 				w->skewb.cubeLoc[face][position].rotation =
 					startLoc[face][position].rotation;
 		}
-	DrawAllPolyhedrons(w);
+	DrawAllPieces(w);
 }
