@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -25,43 +25,35 @@
 
 /* Undo algorithm */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
 #include "TrianglesP.h"
 
 typedef struct _MoveRecord {
-	/* int direction; */
+#if 0
+	int direction;
+#endif
 	unsigned char packed;	/* This makes assumptions on the data. */
 } MoveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord  move;
+	MoveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
 static MoveStack *currMove, *lastMove, *firstMove;
-static int  count;
-static int  startSpace[MAXORIENT];
-static int  startRow[MAXORIENT][ROWTYPES];
-int        *startPosition = NULL;
-
-static void InitStack(void);
-static void PushStack(MoveRecord move);
-static void PopStack(MoveRecord * move);
-static int  EmptyStack(void);
-static void FlushStack(void);
+static int count;
+static int startSpace[MAXORIENT];
+static int startRow[MAXORIENT][ROWTYPES];
+int *startPosition = NULL;
 
 static void
 InitStack(void)
 {
-	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
-	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(lastMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+	if (!(firstMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	firstMove->previous = lastMove->next = NULL;
 	firstMove->next = lastMove;
 	lastMove->previous = firstMove;
@@ -71,8 +63,9 @@ InitStack(void)
 static void
 PushStack(MoveRecord move)
 {
-	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack))))
-		XtError("Not enough memory, exiting.");
+	if (!(currMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 	lastMove->previous->next = currMove;
 	currMove->previous = lastMove->previous;
 	currMove->next = lastMove;
@@ -121,21 +114,25 @@ InitMoves(void)
 static void
 WriteMove(MoveRecord * move, int direction)
 {
-	/* move->direction = direction; */
+#if 0
+	move->direction = direction;
+#endif
 	move->packed = direction & 0xF;
 }
 
 static void
 ReadMove(int *direction, MoveRecord move)
 {
-	/* *direction = move.direction; */
-	*direction = move.packed & 0xF;
+#if 0
+	*direction = move.direction;
+#endif
+	*direction = (int) (move.packed & 0xF);
 }
 
 void
 PutMove(int direction)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	WriteMove(&move, direction);
 	PushStack(move);
@@ -144,7 +141,7 @@ PutMove(int direction)
 void
 GetMove(int *direction)
 {
-	MoveRecord  move;
+	MoveRecord move;
 
 	PopStack(&move);
 	ReadMove(direction, move);
@@ -159,7 +156,7 @@ MadeMoves(void)
 void
 FlushMoves(TrianglesWidget w)
 {
-	int         i;
+	int i;
 
 	FlushStack();
 	startSpace[UP] = w->triangles.spacePosition[UP];
@@ -183,25 +180,25 @@ NumMoves(void)
 void
 ScanMoves(FILE * fp, TrianglesWidget w, int moves)
 {
-	int         direction, l;
-	char        c;
+	int direction, l, c;
 
 	for (l = 0; l < moves; l++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d", &direction);
-		if (!MoveTrianglesDir(w, direction))
-			(void) fprintf(fp, "%d move in direction %d, can not be made.",
-				       l, direction);
+		if (!MoveTrianglesDir(w, direction, INSTANT))
+			(void) fprintf(stderr,
+				"%d move in direction %d, can not be made.",
+				l, direction);
 	}
 }
 
 void
 PrintMoves(FILE * fp)
 {
-	int         direction, counter = 0;
+	int direction, counter = 0;
 
 	currMove = firstMove->next;
-	(void) fprintf(fp, "moves\tdir\n");
+	(void) fprintf(fp, "moves\tdirection\n");
 	while (currMove != lastMove) {
 		ReadMove(&direction, currMove->move);;
 		(void) fprintf(fp, "%d%c\t%d\n", ++counter, SYMBOL, direction);
@@ -212,8 +209,7 @@ PrintMoves(FILE * fp)
 void
 ScanStartPosition(FILE * fp, TrianglesWidget w)
 {
-	int         i, num;
-	char        c;
+	int i, num, c;
 
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	for (i = 0; i < w->triangles.sizeSize; i++) {
@@ -226,15 +222,15 @@ ScanStartPosition(FILE * fp, TrianglesWidget w)
 	}
 	for (i = DOWN; i <= UP; i++) {
 		startRow[i][ROW] = Row(startSpace[i]);
-		startRow[i][TRBL] = TrBl(startSpace[i], startRow[i][ROW]) / 2;
-		startRow[i][TLBR] = TlBr(startSpace[i], startRow[i][ROW]) / 2;
+		startRow[i][TRBL] = TrBl(startSpace[i], startRow[i][ROW]);
+		startRow[i][TLBR] = TlBr(startSpace[i], startRow[i][ROW]);
 	}
 }
 
 void
 PrintStartPosition(FILE * fp, TrianglesWidget w)
 {
-	int         r = 0, p, space, temp;
+	int r = 0, p, space, temp;
 
 	(void) fprintf(fp, "\nstartingPosition%c\n", SYMBOL);
 	for (p = 0; p < w->triangles.sizeSize; p++) {
@@ -254,7 +250,7 @@ PrintStartPosition(FILE * fp, TrianglesWidget w)
 void
 SetStartPosition(TrianglesWidget w)
 {
-	int         i;
+	int i;
 
 	w->triangles.spacePosition[UP] = startSpace[UP];
 	w->triangles.spacePosition[DOWN] = startSpace[DOWN];
@@ -266,5 +262,5 @@ SetStartPosition(TrianglesWidget w)
 	w->triangles.spaceRow[DOWN][ROW] = startRow[DOWN][ROW];
 	for (i = 0; i < w->triangles.sizeSize; i++)
 		w->triangles.tileOfPosition[i] = startPosition[i];
-	DrawAllTiles(w, w->triangles.tileGC, w->triangles.borderGC);
+	DrawAllTiles(w);
 }
